@@ -40,6 +40,14 @@ public void generateIncludes() {
 	output("#include \"");
 	output(outputName);
 	outputln("_stats.h\"");
+	
+	/* 
+	 * Note: Only applies to Linux versions of SWT.
+	 * Include common structs shared between multiple GTK versions.
+	 * Reference Bug 570533, the initial work for separation between 
+	 * functions in different GTK versions.
+	 */
+	if (outputName.equals("gtk3") || outputName.equals("gtk4")) outputln("#include \"os_structs.h\"");
 	outputln();
 }
 
