@@ -14,6 +14,7 @@
  */
 package org.eclipse.swt.tests.win32;
 
+import org.eclipse.swt.widgets.Test_org_eclipse_swt_widgets_Display;
 import org.junit.runner.JUnitCore;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
@@ -22,6 +23,7 @@ import org.junit.runners.Suite;
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
 	Test_org_eclipse_swt_dnd_DND.class,
+	Test_org_eclipse_swt_widgets_Display.class,
 })
 
 public class AllWin32Tests {
